@@ -9,6 +9,7 @@ import json
 import re
 
 from texta_tools.text_processor import TextProcessor
+from texta_tools.embedding import Embedding
 from typing import List, Union
 from .pipeline import get_pipeline_builder
 from .tagging_report import TaggingReport
@@ -33,8 +34,8 @@ class Tagger:
     CLASSIFIERS = pipeline.get_classifier_options()
     VECTORIZERS = pipeline.get_extractor_options()
 
-    def __init__(self, workers=1, description="Tagger", embedding=None, mlp=None, custom_stop_words=[], test_size=0.2,
-                 classifier=CLASSIFIERS[0], vectorizer=VECTORIZERS[0], max_examples_per_class=10000):
+    def __init__(self, workers=1, description="Tagger", embedding=None, mlp=None, custom_stop_words=[], ignore_numbers=False, ignore_punctuation=True,
+                 test_size=0.2, classifier=CLASSIFIERS[0], vectorizer=VECTORIZERS[0], max_examples_per_class=10000, feature_hashing=False):
         # resulting objects etc.
         self.model = None
         self.report = None
@@ -46,14 +47,26 @@ class Tagger:
         self.test_size = test_size
         self.description = description
         self.max_examples_per_class = max_examples_per_class
+        self.feature_hashing = feature_hashing
+
+        # check embedding for phraser
+        phraser = None
+        if isinstance(embedding, Embedding):
+            phraser = embedding.phraser
+        
         # set text processor
-        self.text_processor = self._create_text_processor(embedding, mlp, custom_stop_words)
+        self.text_processor = TextProcessor(
+            phraser=phraser,
+            lemmatizer=mlp,
+            custom_stop_words=custom_stop_words,
+            ignore_numbers=ignore_numbers,
+            ignore_punctuation=ignore_punctuation,
+            text_hashing=feature_hashing)
+        
         # set default sklearn average functions
         self.sklearn_average_binary = "binary"
         self.sklearn_average_multilabel = "micro"
-
         self.scoring_function = None
-
         # metrics map for make_scorer
         self.metric_map = {
             "precision": {"function": precision_score, "needs_pos_label": True},
@@ -102,19 +115,6 @@ class Tagger:
                 pos_label = None
         return pos_label
 
-    def _create_text_processor(self, embedding, mlp, custom_stop_words):
-        """
-        Creates TextProcessor object based on init settings.
-        """
-        # get phraser if present
-        if embedding:
-            phraser = embedding.phraser
-        else:
-            phraser = None
-        # create text processor object
-        text_processor = TextProcessor(phraser=phraser, lemmatizer=mlp, custom_stop_words=custom_stop_words)
-        return text_processor
-
 
     @staticmethod
     def _texts_to_documents(texts):
@@ -373,13 +373,24 @@ class Tagger:
         }
 
 
-    def _add_custom_stop_words(self, stop_words):
+    def _load_stop_words_from_string(self, stop_words_string: str) -> List[str]:
+        """
+        Loads stop words from whitespace-separated string into list.
+        """
+        stop_words = re.split(" |\n|\r\n", stop_words_string)
+        stop_words = [stop_word for stop_word in stop_words if stop_word]
+        return stop_words
+
+
+    def _add_custom_stop_words(self, stop_words: str):
         """
         Splits string of stop words by space or newline and removes empties.
         Updates current TextProcessor custom stop words.
         """
-        stop_words = re.split(' |\n|\r\n', stop_words)
-        stop_words = [stop_word for stop_word in stop_words if stop_word]
+        try:
+            stop_words = json.loads(stop_words)
+        except:
+            stop_words = self._load_stop_words_from_string(stop_words)
         self.text_processor.custom_stop_words = stop_words
 
 
