@@ -20,7 +20,7 @@ class TaggingReport:
 
         self.precision = precision_score(y_test, y_pred, pos_label=pos_label, average=self.average)
         self.f1_score = f1_score(y_test, y_pred, pos_label=pos_label, average=self.average)
-        self.confusion = confusion_matrix(y_test, y_pred)
+        self.confusion = confusion_matrix(y_test, y_pred, labels=classes)
 
         self.recall = recall_score(y_test, y_pred, pos_label=pos_label, average=self.average)
         self.num_features = num_features
